/*
 * jSite2 - Version.java -
 * Copyright © 2008 David Roden
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package net.pterodactylus.jsite.main;

/**
 * Container for version information.
 * 
 * @author David Roden &lt;bombe@freenetproject.org&gt;
 */
public class Version implements Comparable<Version> {

	/** The version of the application. */
	private static final Version VERSION = new Version(0, 9, 0);

	/** The major level of the version. */
	private final int major;

	/** The minor level of the version. */
	private final int minor;

	/** The patch level of the version. */
	private final int patch;

	/**
	 * Creates a new version with the given major level and minor and patch
	 * levels set to <code>0</code>.
	 * 
	 * @param major
	 *            The major level of the version
	 */
	public Version(int major) {
		this(major, 0);
	}

	/**
	 * Creates a new version with the given major and minor level and the patch
	 * level set to <code>0</code>.
	 * 
	 * @param major
	 *            The major level of the version
	 * @param minor
	 *            The minor level of the version
	 */
	public Version(int major, int minor) {
		this(major, minor, 0);
	}

	/**
	 * Creates a new version with the given major, minor, and patch level.
	 * 
	 * @param major
	 *            The major level of the version
	 * @param minor
	 *            The minor level of the version
	 * @param patch
	 *            The patch level of the version
	 */
	public Version(int major, int minor, int patch) {
		this.major = major;
		this.minor = minor;
		this.patch = patch;
	}

	/**
	 * Returns the version of the application.
	 * 
	 * @return The version of the application
	 */
	public static Version getVersion() {
		return VERSION;
	}

	/**
	 * Returns the major level of the version.
	 * 
	 * @return The major level of the version
	 */
	public int getMajor() {
		return major;
	}

	/**
	 * Returns the minor level of the version.
	 * 
	 * @return The minor level of the version
	 */
	public int getMinor() {
		return minor;
	}

	/**
	 * Returns the patch level of the version.
	 * 
	 * @return The patch level of the version
	 */
	public int getPatch() {
		return patch;
	}

	/**
	 * {@inheritDoc}
	 */
	public int compareTo(Version version) {
		return (major != version.major) ? (major - version.major) : ((minor != version.minor) ? (minor - version.minor) : (patch - version.patch));
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		return major + "." + minor + "." + patch;
	}

}
